# MultiSMOTE

Fast implementation of Multi-label SMOTE (Synthetic Minority Over-sampling Technique) for handling imbalanced multilabel datasets.

## Features

- Optimized implementation for multilabel datasets
- Supports both dense and sparse input formats
- Parallel processing support through `n_jobs` parameter
- Compatible with scikit-learn's API

## Installation

```bash
pip install multismote
```

## Usage

```python
from multismote import MultiSMOTE

# Initialize the sampler
smote = MultiSMOTE(k_neighbors=5, random_state=42)

# Fit and resample
X_resampled, y_resampled = smote.fit_resample(X, y)
```

## Parameters

- `k_neighbors`: Number of nearest neighbors to use for generating synthetic samples (default: 5)
- `random_state`: Controls the randomness of the sampling
- `n_jobs`: Number of CPU cores to use during the cross-validation

## Requirements

- Python 3.7+
- numpy >= 1.21.0
- scikit-learn >= 1.0.0
- scipy >= 1.7.0
